==> openrqm-1.0.2.tar.gz: lib/api/workspace_api.dart <==
part of openrqm.api;



class WorkspaceApi {
  final ApiClient apiClient;

  WorkspaceApi([ApiClient apiClient]) : apiClient = apiClient ?? defaultApiClient;

  /// Get a workspace
  ///
  /// 
  Future<RQMWorkspace> getWorkspace() async {
    Object postBody = null;

    // verify required params are set

    // create path and map variables
    String path = "/workspace".replaceAll("{format}","json");

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
    
    List<String> contentTypes = [];

    String contentType = contentTypes.length > 0 ? contentTypes[0] : "application/json";
    List<String> authNames = [];

    if(contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = new MultipartRequest(null, null);
      
      if(hasFields)
        postBody = mp;
    }
    else {
          }

    var response = await apiClient.invokeAPI(path,
                                             'GET',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             contentType,
                                             authNames);

    if(response.statusCode >= 400) {
      throw new ApiException(response.statusCode, response.body);
    } else if(response.body != null) {
      return 
          apiClient.deserialize(response.body, 'RQMWorkspace') as RQMWorkspace ;
    } else {
      return null;
    }
  }
}

==> openrqm-1.0.3.tar.gz: lib/api/workspace_api.dart <==
part of openrqm.api;



class WorkspaceApi {
  final ApiClient apiClient;

  WorkspaceApi([ApiClient apiClient]) : apiClient = apiClient ?? defaultApiClient;

  /// Get a workspace with HTTP info returned
  ///
  /// 
  Future<Response> getWorkspaceWithHttpInfo() async {
    Object postBody;

    // verify required params are set

    // create path and map variables
    String path = "/workspace".replaceAll("{format}","json");

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = [];

    String contentType = contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [];

    if(contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if(hasFields)
        postBody = mp;
    }
    else {
    }

    var response = await apiClient.invokeAPI(path,
                                             'GET',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             contentType,
                                             authNames);
    return response;
  }

  /// Get a workspace
  ///
  /// 
  Future<RQMWorkspace> getWorkspace() async {
    Response response = await getWorkspaceWithHttpInfo();
    if(response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if(response.body != null) {
      return apiClient.deserialize(_decodeBodyBytes(response), 'RQMWorkspace') as RQMWorkspace;
    } else {
      return null;
    }
  }

}
